Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3333)

Unified Diff: base/syslog_logging.h

Issue 2946983002: Move eventlog_provider from //base/win to //chrome/common/win (Closed)
Patch Set: Address review comments on #5 Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « base/BUILD.gn ('k') | base/syslog_logging.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: base/syslog_logging.h
diff --git a/base/syslog_logging.h b/base/syslog_logging.h
index 74f35beaf1aab86beb06d39e8d272c4a7c413ec5..736a5b2efe9de14f9c1e175543d5f69a92b668bf 100644
--- a/base/syslog_logging.h
+++ b/base/syslog_logging.h
@@ -5,7 +5,10 @@
#ifndef BASE_SYSLOG_LOGGING_H_
#define BASE_SYSLOG_LOGGING_H_
+#include <iosfwd>
+
#include "base/logging.h"
+#include "build/build_config.h"
namespace logging {
@@ -17,10 +20,14 @@ namespace logging {
#define SYSLOG(severity) \
SYSLOG_STREAM(severity)
-// Sets the name of the event source for logging to the Windows Event Log.
-// Call this function once before using the SYSLOG macro or otherwise it will
-// behave as a regular LOG macro.
-void BASE_EXPORT SetEventSourceName(const std::string& name);
+#if defined(OS_WIN)
+// Sets the name, category and event id of the event source for logging to the
+// Windows Event Log. Call this function once before using the SYSLOG macro or
+// otherwise it will behave as a regular LOG macro.
+void BASE_EXPORT SetEventSource(const std::string& name,
+ uint16_t category,
+ uint32_t event_id);
+#endif // defined(OS_WIN)
// Creates a formatted message on the system event log. That would be the
// Application Event log on Windows and the messages log file on POSIX systems.
« no previous file with comments | « base/BUILD.gn ('k') | base/syslog_logging.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698